// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: tsl/profiler/protobuf/profile.proto
// Protobuf C++ Version: 5.28.3

#ifndef GOOGLE_PROTOBUF_INCLUDED_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto_2epb_2eh
#define GOOGLE_PROTOBUF_INCLUDED_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 5028003
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/unknown_field_set.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto PROTOBUF_EXPORT

namespace google {
namespace protobuf {
namespace internal {
class AnyMetadata;
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct PROTOBUF_EXPORT TableStruct_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto {
  static const ::uint32_t offsets[];
};
PROTOBUF_EXPORT extern const ::google::protobuf::internal::DescriptorTable
    descriptor_table_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto;
namespace tensorflow {
namespace tfprof {
namespace pprof {
class Function;
struct FunctionDefaultTypeInternal;
PROTOBUF_EXPORT extern FunctionDefaultTypeInternal _Function_default_instance_;
class Label;
struct LabelDefaultTypeInternal;
PROTOBUF_EXPORT extern LabelDefaultTypeInternal _Label_default_instance_;
class Line;
struct LineDefaultTypeInternal;
PROTOBUF_EXPORT extern LineDefaultTypeInternal _Line_default_instance_;
class Location;
struct LocationDefaultTypeInternal;
PROTOBUF_EXPORT extern LocationDefaultTypeInternal _Location_default_instance_;
class Mapping;
struct MappingDefaultTypeInternal;
PROTOBUF_EXPORT extern MappingDefaultTypeInternal _Mapping_default_instance_;
class Profile;
struct ProfileDefaultTypeInternal;
PROTOBUF_EXPORT extern ProfileDefaultTypeInternal _Profile_default_instance_;
class Sample;
struct SampleDefaultTypeInternal;
PROTOBUF_EXPORT extern SampleDefaultTypeInternal _Sample_default_instance_;
class ValueType;
struct ValueTypeDefaultTypeInternal;
PROTOBUF_EXPORT extern ValueTypeDefaultTypeInternal _ValueType_default_instance_;
}  // namespace pprof
}  // namespace tfprof
}  // namespace tensorflow
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google

namespace tensorflow {
namespace tfprof {
namespace pprof {

// ===================================================================


// -------------------------------------------------------------------

class PROTOBUF_EXPORT ValueType final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:tensorflow.tfprof.pprof.ValueType) */ {
 public:
  inline ValueType() : ValueType(nullptr) {}
  ~ValueType() PROTOBUF_FINAL;
  template <typename = void>
  explicit PROTOBUF_CONSTEXPR ValueType(
      ::google::protobuf::internal::ConstantInitialized);

  inline ValueType(const ValueType& from) : ValueType(nullptr, from) {}
  inline ValueType(ValueType&& from) noexcept
      : ValueType(nullptr, std::move(from)) {}
  inline ValueType& operator=(const ValueType& from) {
    CopyFrom(from);
    return *this;
  }
  inline ValueType& operator=(ValueType&& from) noexcept {
    if (this == &from) return *this;
    if (GetArena() == from.GetArena()
#ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetArena() != nullptr
#endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const ValueType& default_instance() {
    return *internal_default_instance();
  }
  static inline const ValueType* internal_default_instance() {
    return reinterpret_cast<const ValueType*>(
        &_ValueType_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(ValueType& a, ValueType& b) { a.Swap(&b); }
  inline void Swap(ValueType* other) {
    if (other == this) return;
#ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() != nullptr && GetArena() == other->GetArena()) {
#else   // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() == other->GetArena()) {
#endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ValueType* other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  ValueType* New(::google::protobuf::Arena* arena = nullptr) const PROTOBUF_FINAL {
    return ::google::protobuf::Message::DefaultConstruct<ValueType>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const ValueType& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const ValueType& from) { ValueType::MergeImpl(*this, from); }

  private:
  static void MergeImpl(
      ::google::protobuf::MessageLite& to_msg,
      const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* _InternalSerialize(
      const MessageLite& msg, ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* arena);
  void SharedDtor();
  void InternalSwap(ValueType* other);
 private:
  friend class ::google::protobuf::internal::AnyMetadata;
  static ::absl::string_view FullMessageName() { return "tensorflow.tfprof.pprof.ValueType"; }

 protected:
  explicit ValueType(::google::protobuf::Arena* arena);
  ValueType(::google::protobuf::Arena* arena, const ValueType& from);
  ValueType(::google::protobuf::Arena* arena, ValueType&& from) noexcept
      : ValueType(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::Message::ClassData* GetClassData() const PROTOBUF_FINAL;
  static const ::google::protobuf::Message::ClassDataFull _class_data_;

 public:
  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kTypeFieldNumber = 1,
    kUnitFieldNumber = 2,
  };
  // int64 type = 1;
  void clear_type() ;
  ::int64_t type() const;
  void set_type(::int64_t value);

  private:
  ::int64_t _internal_type() const;
  void _internal_set_type(::int64_t value);

  public:
  // int64 unit = 2;
  void clear_unit() ;
  ::int64_t unit() const;
  void set_unit(::int64_t value);

  private:
  ::int64_t _internal_unit() const;
  void _internal_set_unit(::int64_t value);

  public:
  // @@protoc_insertion_point(class_scope:tensorflow.tfprof.pprof.ValueType)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<
      1, 2, 0,
      0, 2>
      _table_;


  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(
        ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena);
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena, const Impl_& from,
                          const ValueType& from_msg);
    ::int64_t type_;
    ::int64_t unit_;
    mutable ::google::protobuf::internal::CachedSize _cached_size_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto;
};
// -------------------------------------------------------------------

class PROTOBUF_EXPORT Mapping final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:tensorflow.tfprof.pprof.Mapping) */ {
 public:
  inline Mapping() : Mapping(nullptr) {}
  ~Mapping() PROTOBUF_FINAL;
  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Mapping(
      ::google::protobuf::internal::ConstantInitialized);

  inline Mapping(const Mapping& from) : Mapping(nullptr, from) {}
  inline Mapping(Mapping&& from) noexcept
      : Mapping(nullptr, std::move(from)) {}
  inline Mapping& operator=(const Mapping& from) {
    CopyFrom(from);
    return *this;
  }
  inline Mapping& operator=(Mapping&& from) noexcept {
    if (this == &from) return *this;
    if (GetArena() == from.GetArena()
#ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetArena() != nullptr
#endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Mapping& default_instance() {
    return *internal_default_instance();
  }
  static inline const Mapping* internal_default_instance() {
    return reinterpret_cast<const Mapping*>(
        &_Mapping_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 4;
  friend void swap(Mapping& a, Mapping& b) { a.Swap(&b); }
  inline void Swap(Mapping* other) {
    if (other == this) return;
#ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() != nullptr && GetArena() == other->GetArena()) {
#else   // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() == other->GetArena()) {
#endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Mapping* other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Mapping* New(::google::protobuf::Arena* arena = nullptr) const PROTOBUF_FINAL {
    return ::google::protobuf::Message::DefaultConstruct<Mapping>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Mapping& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Mapping& from) { Mapping::MergeImpl(*this, from); }

  private:
  static void MergeImpl(
      ::google::protobuf::MessageLite& to_msg,
      const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* _InternalSerialize(
      const MessageLite& msg, ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* arena);
  void SharedDtor();
  void InternalSwap(Mapping* other);
 private:
  friend class ::google::protobuf::internal::AnyMetadata;
  static ::absl::string_view FullMessageName() { return "tensorflow.tfprof.pprof.Mapping"; }

 protected:
  explicit Mapping(::google::protobuf::Arena* arena);
  Mapping(::google::protobuf::Arena* arena, const Mapping& from);
  Mapping(::google::protobuf::Arena* arena, Mapping&& from) noexcept
      : Mapping(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::Message::ClassData* GetClassData() const PROTOBUF_FINAL;
  static const ::google::protobuf::Message::ClassDataFull _class_data_;

 public:
  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kIdFieldNumber = 1,
    kMemoryStartFieldNumber = 2,
    kMemoryLimitFieldNumber = 3,
    kFileOffsetFieldNumber = 4,
    kFilenameFieldNumber = 5,
    kBuildIdFieldNumber = 6,
    kHasFunctionsFieldNumber = 7,
    kHasFilenamesFieldNumber = 8,
    kHasLineNumbersFieldNumber = 9,
    kHasInlineFramesFieldNumber = 10,
  };
  // uint64 id = 1;
  void clear_id() ;
  ::uint64_t id() const;
  void set_id(::uint64_t value);

  private:
  ::uint64_t _internal_id() const;
  void _internal_set_id(::uint64_t value);

  public:
  // uint64 memory_start = 2;
  void clear_memory_start() ;
  ::uint64_t memory_start() const;
  void set_memory_start(::uint64_t value);

  private:
  ::uint64_t _internal_memory_start() const;
  void _internal_set_memory_start(::uint64_t value);

  public:
  // uint64 memory_limit = 3;
  void clear_memory_limit() ;
  ::uint64_t memory_limit() const;
  void set_memory_limit(::uint64_t value);

  private:
  ::uint64_t _internal_memory_limit() const;
  void _internal_set_memory_limit(::uint64_t value);

  public:
  // uint64 file_offset = 4;
  void clear_file_offset() ;
  ::uint64_t file_offset() const;
  void set_file_offset(::uint64_t value);

  private:
  ::uint64_t _internal_file_offset() const;
  void _internal_set_file_offset(::uint64_t value);

  public:
  // int64 filename = 5;
  void clear_filename() ;
  ::int64_t filename() const;
  void set_filename(::int64_t value);

  private:
  ::int64_t _internal_filename() const;
  void _internal_set_filename(::int64_t value);

  public:
  // int64 build_id = 6;
  void clear_build_id() ;
  ::int64_t build_id() const;
  void set_build_id(::int64_t value);

  private:
  ::int64_t _internal_build_id() const;
  void _internal_set_build_id(::int64_t value);

  public:
  // bool has_functions = 7;
  void clear_has_functions() ;
  bool has_functions() const;
  void set_has_functions(bool value);

  private:
  bool _internal_has_functions() const;
  void _internal_set_has_functions(bool value);

  public:
  // bool has_filenames = 8;
  void clear_has_filenames() ;
  bool has_filenames() const;
  void set_has_filenames(bool value);

  private:
  bool _internal_has_filenames() const;
  void _internal_set_has_filenames(bool value);

  public:
  // bool has_line_numbers = 9;
  void clear_has_line_numbers() ;
  bool has_line_numbers() const;
  void set_has_line_numbers(bool value);

  private:
  bool _internal_has_line_numbers() const;
  void _internal_set_has_line_numbers(bool value);

  public:
  // bool has_inline_frames = 10;
  void clear_has_inline_frames() ;
  bool has_inline_frames() const;
  void set_has_inline_frames(bool value);

  private:
  bool _internal_has_inline_frames() const;
  void _internal_set_has_inline_frames(bool value);

  public:
  // @@protoc_insertion_point(class_scope:tensorflow.tfprof.pprof.Mapping)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<
      4, 10, 0,
      0, 2>
      _table_;


  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(
        ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena);
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena, const Impl_& from,
                          const Mapping& from_msg);
    ::uint64_t id_;
    ::uint64_t memory_start_;
    ::uint64_t memory_limit_;
    ::uint64_t file_offset_;
    ::int64_t filename_;
    ::int64_t build_id_;
    bool has_functions_;
    bool has_filenames_;
    bool has_line_numbers_;
    bool has_inline_frames_;
    mutable ::google::protobuf::internal::CachedSize _cached_size_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto;
};
// -------------------------------------------------------------------

class PROTOBUF_EXPORT Line final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:tensorflow.tfprof.pprof.Line) */ {
 public:
  inline Line() : Line(nullptr) {}
  ~Line() PROTOBUF_FINAL;
  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Line(
      ::google::protobuf::internal::ConstantInitialized);

  inline Line(const Line& from) : Line(nullptr, from) {}
  inline Line(Line&& from) noexcept
      : Line(nullptr, std::move(from)) {}
  inline Line& operator=(const Line& from) {
    CopyFrom(from);
    return *this;
  }
  inline Line& operator=(Line&& from) noexcept {
    if (this == &from) return *this;
    if (GetArena() == from.GetArena()
#ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetArena() != nullptr
#endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Line& default_instance() {
    return *internal_default_instance();
  }
  static inline const Line* internal_default_instance() {
    return reinterpret_cast<const Line*>(
        &_Line_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 6;
  friend void swap(Line& a, Line& b) { a.Swap(&b); }
  inline void Swap(Line* other) {
    if (other == this) return;
#ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() != nullptr && GetArena() == other->GetArena()) {
#else   // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() == other->GetArena()) {
#endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Line* other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Line* New(::google::protobuf::Arena* arena = nullptr) const PROTOBUF_FINAL {
    return ::google::protobuf::Message::DefaultConstruct<Line>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Line& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Line& from) { Line::MergeImpl(*this, from); }

  private:
  static void MergeImpl(
      ::google::protobuf::MessageLite& to_msg,
      const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* _InternalSerialize(
      const MessageLite& msg, ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* arena);
  void SharedDtor();
  void InternalSwap(Line* other);
 private:
  friend class ::google::protobuf::internal::AnyMetadata;
  static ::absl::string_view FullMessageName() { return "tensorflow.tfprof.pprof.Line"; }

 protected:
  explicit Line(::google::protobuf::Arena* arena);
  Line(::google::protobuf::Arena* arena, const Line& from);
  Line(::google::protobuf::Arena* arena, Line&& from) noexcept
      : Line(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::Message::ClassData* GetClassData() const PROTOBUF_FINAL;
  static const ::google::protobuf::Message::ClassDataFull _class_data_;

 public:
  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kFunctionIdFieldNumber = 1,
    kLineFieldNumber = 2,
  };
  // uint64 function_id = 1;
  void clear_function_id() ;
  ::uint64_t function_id() const;
  void set_function_id(::uint64_t value);

  private:
  ::uint64_t _internal_function_id() const;
  void _internal_set_function_id(::uint64_t value);

  public:
  // int64 line = 2;
  void clear_line() ;
  ::int64_t line() const;
  void set_line(::int64_t value);

  private:
  ::int64_t _internal_line() const;
  void _internal_set_line(::int64_t value);

  public:
  // @@protoc_insertion_point(class_scope:tensorflow.tfprof.pprof.Line)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<
      1, 2, 0,
      0, 2>
      _table_;


  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(
        ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena);
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena, const Impl_& from,
                          const Line& from_msg);
    ::uint64_t function_id_;
    ::int64_t line_;
    mutable ::google::protobuf::internal::CachedSize _cached_size_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto;
};
// -------------------------------------------------------------------

class PROTOBUF_EXPORT Label final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:tensorflow.tfprof.pprof.Label) */ {
 public:
  inline Label() : Label(nullptr) {}
  ~Label() PROTOBUF_FINAL;
  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Label(
      ::google::protobuf::internal::ConstantInitialized);

  inline Label(const Label& from) : Label(nullptr, from) {}
  inline Label(Label&& from) noexcept
      : Label(nullptr, std::move(from)) {}
  inline Label& operator=(const Label& from) {
    CopyFrom(from);
    return *this;
  }
  inline Label& operator=(Label&& from) noexcept {
    if (this == &from) return *this;
    if (GetArena() == from.GetArena()
#ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetArena() != nullptr
#endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Label& default_instance() {
    return *internal_default_instance();
  }
  static inline const Label* internal_default_instance() {
    return reinterpret_cast<const Label*>(
        &_Label_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 3;
  friend void swap(Label& a, Label& b) { a.Swap(&b); }
  inline void Swap(Label* other) {
    if (other == this) return;
#ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() != nullptr && GetArena() == other->GetArena()) {
#else   // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() == other->GetArena()) {
#endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Label* other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Label* New(::google::protobuf::Arena* arena = nullptr) const PROTOBUF_FINAL {
    return ::google::protobuf::Message::DefaultConstruct<Label>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Label& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Label& from) { Label::MergeImpl(*this, from); }

  private:
  static void MergeImpl(
      ::google::protobuf::MessageLite& to_msg,
      const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* _InternalSerialize(
      const MessageLite& msg, ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* arena);
  void SharedDtor();
  void InternalSwap(Label* other);
 private:
  friend class ::google::protobuf::internal::AnyMetadata;
  static ::absl::string_view FullMessageName() { return "tensorflow.tfprof.pprof.Label"; }

 protected:
  explicit Label(::google::protobuf::Arena* arena);
  Label(::google::protobuf::Arena* arena, const Label& from);
  Label(::google::protobuf::Arena* arena, Label&& from) noexcept
      : Label(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::Message::ClassData* GetClassData() const PROTOBUF_FINAL;
  static const ::google::protobuf::Message::ClassDataFull _class_data_;

 public:
  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kKeyFieldNumber = 1,
    kStrFieldNumber = 2,
    kNumFieldNumber = 3,
  };
  // int64 key = 1;
  void clear_key() ;
  ::int64_t key() const;
  void set_key(::int64_t value);

  private:
  ::int64_t _internal_key() const;
  void _internal_set_key(::int64_t value);

  public:
  // int64 str = 2;
  void clear_str() ;
  ::int64_t str() const;
  void set_str(::int64_t value);

  private:
  ::int64_t _internal_str() const;
  void _internal_set_str(::int64_t value);

  public:
  // int64 num = 3;
  void clear_num() ;
  ::int64_t num() const;
  void set_num(::int64_t value);

  private:
  ::int64_t _internal_num() const;
  void _internal_set_num(::int64_t value);

  public:
  // @@protoc_insertion_point(class_scope:tensorflow.tfprof.pprof.Label)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<
      2, 3, 0,
      0, 2>
      _table_;


  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(
        ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena);
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena, const Impl_& from,
                          const Label& from_msg);
    ::int64_t key_;
    ::int64_t str_;
    ::int64_t num_;
    mutable ::google::protobuf::internal::CachedSize _cached_size_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto;
};
// -------------------------------------------------------------------

class PROTOBUF_EXPORT Function final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:tensorflow.tfprof.pprof.Function) */ {
 public:
  inline Function() : Function(nullptr) {}
  ~Function() PROTOBUF_FINAL;
  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Function(
      ::google::protobuf::internal::ConstantInitialized);

  inline Function(const Function& from) : Function(nullptr, from) {}
  inline Function(Function&& from) noexcept
      : Function(nullptr, std::move(from)) {}
  inline Function& operator=(const Function& from) {
    CopyFrom(from);
    return *this;
  }
  inline Function& operator=(Function&& from) noexcept {
    if (this == &from) return *this;
    if (GetArena() == from.GetArena()
#ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetArena() != nullptr
#endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Function& default_instance() {
    return *internal_default_instance();
  }
  static inline const Function* internal_default_instance() {
    return reinterpret_cast<const Function*>(
        &_Function_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 7;
  friend void swap(Function& a, Function& b) { a.Swap(&b); }
  inline void Swap(Function* other) {
    if (other == this) return;
#ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() != nullptr && GetArena() == other->GetArena()) {
#else   // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() == other->GetArena()) {
#endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Function* other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Function* New(::google::protobuf::Arena* arena = nullptr) const PROTOBUF_FINAL {
    return ::google::protobuf::Message::DefaultConstruct<Function>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Function& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Function& from) { Function::MergeImpl(*this, from); }

  private:
  static void MergeImpl(
      ::google::protobuf::MessageLite& to_msg,
      const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* _InternalSerialize(
      const MessageLite& msg, ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* arena);
  void SharedDtor();
  void InternalSwap(Function* other);
 private:
  friend class ::google::protobuf::internal::AnyMetadata;
  static ::absl::string_view FullMessageName() { return "tensorflow.tfprof.pprof.Function"; }

 protected:
  explicit Function(::google::protobuf::Arena* arena);
  Function(::google::protobuf::Arena* arena, const Function& from);
  Function(::google::protobuf::Arena* arena, Function&& from) noexcept
      : Function(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::Message::ClassData* GetClassData() const PROTOBUF_FINAL;
  static const ::google::protobuf::Message::ClassDataFull _class_data_;

 public:
  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kIdFieldNumber = 1,
    kNameFieldNumber = 2,
    kSystemNameFieldNumber = 3,
    kFilenameFieldNumber = 4,
    kStartLineFieldNumber = 5,
  };
  // uint64 id = 1;
  void clear_id() ;
  ::uint64_t id() const;
  void set_id(::uint64_t value);

  private:
  ::uint64_t _internal_id() const;
  void _internal_set_id(::uint64_t value);

  public:
  // int64 name = 2;
  void clear_name() ;
  ::int64_t name() const;
  void set_name(::int64_t value);

  private:
  ::int64_t _internal_name() const;
  void _internal_set_name(::int64_t value);

  public:
  // int64 system_name = 3;
  void clear_system_name() ;
  ::int64_t system_name() const;
  void set_system_name(::int64_t value);

  private:
  ::int64_t _internal_system_name() const;
  void _internal_set_system_name(::int64_t value);

  public:
  // int64 filename = 4;
  void clear_filename() ;
  ::int64_t filename() const;
  void set_filename(::int64_t value);

  private:
  ::int64_t _internal_filename() const;
  void _internal_set_filename(::int64_t value);

  public:
  // int64 start_line = 5;
  void clear_start_line() ;
  ::int64_t start_line() const;
  void set_start_line(::int64_t value);

  private:
  ::int64_t _internal_start_line() const;
  void _internal_set_start_line(::int64_t value);

  public:
  // @@protoc_insertion_point(class_scope:tensorflow.tfprof.pprof.Function)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<
      3, 5, 0,
      0, 2>
      _table_;


  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(
        ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena);
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena, const Impl_& from,
                          const Function& from_msg);
    ::uint64_t id_;
    ::int64_t name_;
    ::int64_t system_name_;
    ::int64_t filename_;
    ::int64_t start_line_;
    mutable ::google::protobuf::internal::CachedSize _cached_size_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto;
};
// -------------------------------------------------------------------

class PROTOBUF_EXPORT Sample final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:tensorflow.tfprof.pprof.Sample) */ {
 public:
  inline Sample() : Sample(nullptr) {}
  ~Sample() PROTOBUF_FINAL;
  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Sample(
      ::google::protobuf::internal::ConstantInitialized);

  inline Sample(const Sample& from) : Sample(nullptr, from) {}
  inline Sample(Sample&& from) noexcept
      : Sample(nullptr, std::move(from)) {}
  inline Sample& operator=(const Sample& from) {
    CopyFrom(from);
    return *this;
  }
  inline Sample& operator=(Sample&& from) noexcept {
    if (this == &from) return *this;
    if (GetArena() == from.GetArena()
#ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetArena() != nullptr
#endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Sample& default_instance() {
    return *internal_default_instance();
  }
  static inline const Sample* internal_default_instance() {
    return reinterpret_cast<const Sample*>(
        &_Sample_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 2;
  friend void swap(Sample& a, Sample& b) { a.Swap(&b); }
  inline void Swap(Sample* other) {
    if (other == this) return;
#ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() != nullptr && GetArena() == other->GetArena()) {
#else   // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() == other->GetArena()) {
#endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Sample* other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Sample* New(::google::protobuf::Arena* arena = nullptr) const PROTOBUF_FINAL {
    return ::google::protobuf::Message::DefaultConstruct<Sample>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Sample& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Sample& from) { Sample::MergeImpl(*this, from); }

  private:
  static void MergeImpl(
      ::google::protobuf::MessageLite& to_msg,
      const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* _InternalSerialize(
      const MessageLite& msg, ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* arena);
  void SharedDtor();
  void InternalSwap(Sample* other);
 private:
  friend class ::google::protobuf::internal::AnyMetadata;
  static ::absl::string_view FullMessageName() { return "tensorflow.tfprof.pprof.Sample"; }

 protected:
  explicit Sample(::google::protobuf::Arena* arena);
  Sample(::google::protobuf::Arena* arena, const Sample& from);
  Sample(::google::protobuf::Arena* arena, Sample&& from) noexcept
      : Sample(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::Message::ClassData* GetClassData() const PROTOBUF_FINAL;
  static const ::google::protobuf::Message::ClassDataFull _class_data_;

 public:
  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kLocationIdFieldNumber = 1,
    kValueFieldNumber = 2,
    kLabelFieldNumber = 3,
  };
  // repeated uint64 location_id = 1;
  int location_id_size() const;
  private:
  int _internal_location_id_size() const;

  public:
  void clear_location_id() ;
  ::uint64_t location_id(int index) const;
  void set_location_id(int index, ::uint64_t value);
  void add_location_id(::uint64_t value);
  const ::google::protobuf::RepeatedField<::uint64_t>& location_id() const;
  ::google::protobuf::RepeatedField<::uint64_t>* mutable_location_id();

  private:
  const ::google::protobuf::RepeatedField<::uint64_t>& _internal_location_id() const;
  ::google::protobuf::RepeatedField<::uint64_t>* _internal_mutable_location_id();

  public:
  // repeated int64 value = 2;
  int value_size() const;
  private:
  int _internal_value_size() const;

  public:
  void clear_value() ;
  ::int64_t value(int index) const;
  void set_value(int index, ::int64_t value);
  void add_value(::int64_t value);
  const ::google::protobuf::RepeatedField<::int64_t>& value() const;
  ::google::protobuf::RepeatedField<::int64_t>* mutable_value();

  private:
  const ::google::protobuf::RepeatedField<::int64_t>& _internal_value() const;
  ::google::protobuf::RepeatedField<::int64_t>* _internal_mutable_value();

  public:
  // repeated .tensorflow.tfprof.pprof.Label label = 3;
  int label_size() const;
  private:
  int _internal_label_size() const;

  public:
  void clear_label() ;
  ::tensorflow::tfprof::pprof::Label* mutable_label(int index);
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Label>* mutable_label();

  private:
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Label>& _internal_label() const;
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Label>* _internal_mutable_label();
  public:
  const ::tensorflow::tfprof::pprof::Label& label(int index) const;
  ::tensorflow::tfprof::pprof::Label* add_label();
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Label>& label() const;
  // @@protoc_insertion_point(class_scope:tensorflow.tfprof.pprof.Sample)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<
      2, 3, 1,
      0, 2>
      _table_;


  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(
        ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena);
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena, const Impl_& from,
                          const Sample& from_msg);
    ::google::protobuf::RepeatedField<::uint64_t> location_id_;
    mutable ::google::protobuf::internal::CachedSize _location_id_cached_byte_size_;
    ::google::protobuf::RepeatedField<::int64_t> value_;
    mutable ::google::protobuf::internal::CachedSize _value_cached_byte_size_;
    ::google::protobuf::RepeatedPtrField< ::tensorflow::tfprof::pprof::Label > label_;
    mutable ::google::protobuf::internal::CachedSize _cached_size_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto;
};
// -------------------------------------------------------------------

class PROTOBUF_EXPORT Location final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:tensorflow.tfprof.pprof.Location) */ {
 public:
  inline Location() : Location(nullptr) {}
  ~Location() PROTOBUF_FINAL;
  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Location(
      ::google::protobuf::internal::ConstantInitialized);

  inline Location(const Location& from) : Location(nullptr, from) {}
  inline Location(Location&& from) noexcept
      : Location(nullptr, std::move(from)) {}
  inline Location& operator=(const Location& from) {
    CopyFrom(from);
    return *this;
  }
  inline Location& operator=(Location&& from) noexcept {
    if (this == &from) return *this;
    if (GetArena() == from.GetArena()
#ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetArena() != nullptr
#endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Location& default_instance() {
    return *internal_default_instance();
  }
  static inline const Location* internal_default_instance() {
    return reinterpret_cast<const Location*>(
        &_Location_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 5;
  friend void swap(Location& a, Location& b) { a.Swap(&b); }
  inline void Swap(Location* other) {
    if (other == this) return;
#ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() != nullptr && GetArena() == other->GetArena()) {
#else   // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() == other->GetArena()) {
#endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Location* other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Location* New(::google::protobuf::Arena* arena = nullptr) const PROTOBUF_FINAL {
    return ::google::protobuf::Message::DefaultConstruct<Location>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Location& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Location& from) { Location::MergeImpl(*this, from); }

  private:
  static void MergeImpl(
      ::google::protobuf::MessageLite& to_msg,
      const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* _InternalSerialize(
      const MessageLite& msg, ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* arena);
  void SharedDtor();
  void InternalSwap(Location* other);
 private:
  friend class ::google::protobuf::internal::AnyMetadata;
  static ::absl::string_view FullMessageName() { return "tensorflow.tfprof.pprof.Location"; }

 protected:
  explicit Location(::google::protobuf::Arena* arena);
  Location(::google::protobuf::Arena* arena, const Location& from);
  Location(::google::protobuf::Arena* arena, Location&& from) noexcept
      : Location(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::Message::ClassData* GetClassData() const PROTOBUF_FINAL;
  static const ::google::protobuf::Message::ClassDataFull _class_data_;

 public:
  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kLineFieldNumber = 4,
    kIdFieldNumber = 1,
    kMappingIdFieldNumber = 2,
    kAddressFieldNumber = 3,
  };
  // repeated .tensorflow.tfprof.pprof.Line line = 4;
  int line_size() const;
  private:
  int _internal_line_size() const;

  public:
  void clear_line() ;
  ::tensorflow::tfprof::pprof::Line* mutable_line(int index);
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Line>* mutable_line();

  private:
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Line>& _internal_line() const;
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Line>* _internal_mutable_line();
  public:
  const ::tensorflow::tfprof::pprof::Line& line(int index) const;
  ::tensorflow::tfprof::pprof::Line* add_line();
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Line>& line() const;
  // uint64 id = 1;
  void clear_id() ;
  ::uint64_t id() const;
  void set_id(::uint64_t value);

  private:
  ::uint64_t _internal_id() const;
  void _internal_set_id(::uint64_t value);

  public:
  // uint64 mapping_id = 2;
  void clear_mapping_id() ;
  ::uint64_t mapping_id() const;
  void set_mapping_id(::uint64_t value);

  private:
  ::uint64_t _internal_mapping_id() const;
  void _internal_set_mapping_id(::uint64_t value);

  public:
  // uint64 address = 3;
  void clear_address() ;
  ::uint64_t address() const;
  void set_address(::uint64_t value);

  private:
  ::uint64_t _internal_address() const;
  void _internal_set_address(::uint64_t value);

  public:
  // @@protoc_insertion_point(class_scope:tensorflow.tfprof.pprof.Location)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<
      2, 4, 1,
      0, 2>
      _table_;


  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(
        ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena);
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena, const Impl_& from,
                          const Location& from_msg);
    ::google::protobuf::RepeatedPtrField< ::tensorflow::tfprof::pprof::Line > line_;
    ::uint64_t id_;
    ::uint64_t mapping_id_;
    ::uint64_t address_;
    mutable ::google::protobuf::internal::CachedSize _cached_size_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto;
};
// -------------------------------------------------------------------

class PROTOBUF_EXPORT Profile final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:tensorflow.tfprof.pprof.Profile) */ {
 public:
  inline Profile() : Profile(nullptr) {}
  ~Profile() PROTOBUF_FINAL;
  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Profile(
      ::google::protobuf::internal::ConstantInitialized);

  inline Profile(const Profile& from) : Profile(nullptr, from) {}
  inline Profile(Profile&& from) noexcept
      : Profile(nullptr, std::move(from)) {}
  inline Profile& operator=(const Profile& from) {
    CopyFrom(from);
    return *this;
  }
  inline Profile& operator=(Profile&& from) noexcept {
    if (this == &from) return *this;
    if (GetArena() == from.GetArena()
#ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetArena() != nullptr
#endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Profile& default_instance() {
    return *internal_default_instance();
  }
  static inline const Profile* internal_default_instance() {
    return reinterpret_cast<const Profile*>(
        &_Profile_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(Profile& a, Profile& b) { a.Swap(&b); }
  inline void Swap(Profile* other) {
    if (other == this) return;
#ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() != nullptr && GetArena() == other->GetArena()) {
#else   // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetArena() == other->GetArena()) {
#endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Profile* other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Profile* New(::google::protobuf::Arena* arena = nullptr) const PROTOBUF_FINAL {
    return ::google::protobuf::Message::DefaultConstruct<Profile>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Profile& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Profile& from) { Profile::MergeImpl(*this, from); }

  private:
  static void MergeImpl(
      ::google::protobuf::MessageLite& to_msg,
      const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* _InternalSerialize(
      const MessageLite& msg, ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* _InternalSerialize(
      ::uint8_t* target,
      ::google::protobuf::io::EpsCopyOutputStream* stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* arena);
  void SharedDtor();
  void InternalSwap(Profile* other);
 private:
  friend class ::google::protobuf::internal::AnyMetadata;
  static ::absl::string_view FullMessageName() { return "tensorflow.tfprof.pprof.Profile"; }

 protected:
  explicit Profile(::google::protobuf::Arena* arena);
  Profile(::google::protobuf::Arena* arena, const Profile& from);
  Profile(::google::protobuf::Arena* arena, Profile&& from) noexcept
      : Profile(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::Message::ClassData* GetClassData() const PROTOBUF_FINAL;
  static const ::google::protobuf::Message::ClassDataFull _class_data_;

 public:
  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kSampleTypeFieldNumber = 1,
    kSampleFieldNumber = 2,
    kMappingFieldNumber = 3,
    kLocationFieldNumber = 4,
    kFunctionFieldNumber = 5,
    kStringTableFieldNumber = 6,
    kCommentFieldNumber = 13,
    kPeriodTypeFieldNumber = 11,
    kDropFramesFieldNumber = 7,
    kKeepFramesFieldNumber = 8,
    kTimeNanosFieldNumber = 9,
    kDurationNanosFieldNumber = 10,
    kPeriodFieldNumber = 12,
    kDefaultSampleTypeFieldNumber = 14,
  };
  // repeated .tensorflow.tfprof.pprof.ValueType sample_type = 1;
  int sample_type_size() const;
  private:
  int _internal_sample_type_size() const;

  public:
  void clear_sample_type() ;
  ::tensorflow::tfprof::pprof::ValueType* mutable_sample_type(int index);
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::ValueType>* mutable_sample_type();

  private:
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::ValueType>& _internal_sample_type() const;
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::ValueType>* _internal_mutable_sample_type();
  public:
  const ::tensorflow::tfprof::pprof::ValueType& sample_type(int index) const;
  ::tensorflow::tfprof::pprof::ValueType* add_sample_type();
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::ValueType>& sample_type() const;
  // repeated .tensorflow.tfprof.pprof.Sample sample = 2;
  int sample_size() const;
  private:
  int _internal_sample_size() const;

  public:
  void clear_sample() ;
  ::tensorflow::tfprof::pprof::Sample* mutable_sample(int index);
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Sample>* mutable_sample();

  private:
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Sample>& _internal_sample() const;
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Sample>* _internal_mutable_sample();
  public:
  const ::tensorflow::tfprof::pprof::Sample& sample(int index) const;
  ::tensorflow::tfprof::pprof::Sample* add_sample();
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Sample>& sample() const;
  // repeated .tensorflow.tfprof.pprof.Mapping mapping = 3;
  int mapping_size() const;
  private:
  int _internal_mapping_size() const;

  public:
  void clear_mapping() ;
  ::tensorflow::tfprof::pprof::Mapping* mutable_mapping(int index);
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Mapping>* mutable_mapping();

  private:
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Mapping>& _internal_mapping() const;
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Mapping>* _internal_mutable_mapping();
  public:
  const ::tensorflow::tfprof::pprof::Mapping& mapping(int index) const;
  ::tensorflow::tfprof::pprof::Mapping* add_mapping();
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Mapping>& mapping() const;
  // repeated .tensorflow.tfprof.pprof.Location location = 4;
  int location_size() const;
  private:
  int _internal_location_size() const;

  public:
  void clear_location() ;
  ::tensorflow::tfprof::pprof::Location* mutable_location(int index);
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Location>* mutable_location();

  private:
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Location>& _internal_location() const;
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Location>* _internal_mutable_location();
  public:
  const ::tensorflow::tfprof::pprof::Location& location(int index) const;
  ::tensorflow::tfprof::pprof::Location* add_location();
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Location>& location() const;
  // repeated .tensorflow.tfprof.pprof.Function function = 5;
  int function_size() const;
  private:
  int _internal_function_size() const;

  public:
  void clear_function() ;
  ::tensorflow::tfprof::pprof::Function* mutable_function(int index);
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Function>* mutable_function();

  private:
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Function>& _internal_function() const;
  ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Function>* _internal_mutable_function();
  public:
  const ::tensorflow::tfprof::pprof::Function& function(int index) const;
  ::tensorflow::tfprof::pprof::Function* add_function();
  const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Function>& function() const;
  // repeated string string_table = 6;
  int string_table_size() const;
  private:
  int _internal_string_table_size() const;

  public:
  void clear_string_table() ;
  const std::string& string_table(int index) const;
  std::string* mutable_string_table(int index);
  template <typename Arg_ = const std::string&, typename... Args_>
  void set_string_table(int index, Arg_&& value, Args_... args);
  std::string* add_string_table();
  template <typename Arg_ = const std::string&, typename... Args_>
  void add_string_table(Arg_&& value, Args_... args);
  const ::google::protobuf::RepeatedPtrField<std::string>& string_table() const;
  ::google::protobuf::RepeatedPtrField<std::string>* mutable_string_table();

  private:
  const ::google::protobuf::RepeatedPtrField<std::string>& _internal_string_table() const;
  ::google::protobuf::RepeatedPtrField<std::string>* _internal_mutable_string_table();

  public:
  // repeated int64 comment = 13;
  int comment_size() const;
  private:
  int _internal_comment_size() const;

  public:
  void clear_comment() ;
  ::int64_t comment(int index) const;
  void set_comment(int index, ::int64_t value);
  void add_comment(::int64_t value);
  const ::google::protobuf::RepeatedField<::int64_t>& comment() const;
  ::google::protobuf::RepeatedField<::int64_t>* mutable_comment();

  private:
  const ::google::protobuf::RepeatedField<::int64_t>& _internal_comment() const;
  ::google::protobuf::RepeatedField<::int64_t>* _internal_mutable_comment();

  public:
  // .tensorflow.tfprof.pprof.ValueType period_type = 11;
  bool has_period_type() const;
  void clear_period_type() ;
  const ::tensorflow::tfprof::pprof::ValueType& period_type() const;
  PROTOBUF_NODISCARD ::tensorflow::tfprof::pprof::ValueType* release_period_type();
  ::tensorflow::tfprof::pprof::ValueType* mutable_period_type();
  void set_allocated_period_type(::tensorflow::tfprof::pprof::ValueType* value);
  void unsafe_arena_set_allocated_period_type(::tensorflow::tfprof::pprof::ValueType* value);
  ::tensorflow::tfprof::pprof::ValueType* unsafe_arena_release_period_type();

  private:
  const ::tensorflow::tfprof::pprof::ValueType& _internal_period_type() const;
  ::tensorflow::tfprof::pprof::ValueType* _internal_mutable_period_type();

  public:
  // int64 drop_frames = 7;
  void clear_drop_frames() ;
  ::int64_t drop_frames() const;
  void set_drop_frames(::int64_t value);

  private:
  ::int64_t _internal_drop_frames() const;
  void _internal_set_drop_frames(::int64_t value);

  public:
  // int64 keep_frames = 8;
  void clear_keep_frames() ;
  ::int64_t keep_frames() const;
  void set_keep_frames(::int64_t value);

  private:
  ::int64_t _internal_keep_frames() const;
  void _internal_set_keep_frames(::int64_t value);

  public:
  // int64 time_nanos = 9;
  void clear_time_nanos() ;
  ::int64_t time_nanos() const;
  void set_time_nanos(::int64_t value);

  private:
  ::int64_t _internal_time_nanos() const;
  void _internal_set_time_nanos(::int64_t value);

  public:
  // int64 duration_nanos = 10;
  void clear_duration_nanos() ;
  ::int64_t duration_nanos() const;
  void set_duration_nanos(::int64_t value);

  private:
  ::int64_t _internal_duration_nanos() const;
  void _internal_set_duration_nanos(::int64_t value);

  public:
  // int64 period = 12;
  void clear_period() ;
  ::int64_t period() const;
  void set_period(::int64_t value);

  private:
  ::int64_t _internal_period() const;
  void _internal_set_period(::int64_t value);

  public:
  // int64 default_sample_type = 14;
  void clear_default_sample_type() ;
  ::int64_t default_sample_type() const;
  void set_default_sample_type(::int64_t value);

  private:
  ::int64_t _internal_default_sample_type() const;
  void _internal_set_default_sample_type(::int64_t value);

  public:
  // @@protoc_insertion_point(class_scope:tensorflow.tfprof.pprof.Profile)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<
      4, 14, 6,
      60, 2>
      _table_;


  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(
        ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena);
    inline explicit Impl_(::google::protobuf::internal::InternalVisibility visibility,
                          ::google::protobuf::Arena* arena, const Impl_& from,
                          const Profile& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    mutable ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::tensorflow::tfprof::pprof::ValueType > sample_type_;
    ::google::protobuf::RepeatedPtrField< ::tensorflow::tfprof::pprof::Sample > sample_;
    ::google::protobuf::RepeatedPtrField< ::tensorflow::tfprof::pprof::Mapping > mapping_;
    ::google::protobuf::RepeatedPtrField< ::tensorflow::tfprof::pprof::Location > location_;
    ::google::protobuf::RepeatedPtrField< ::tensorflow::tfprof::pprof::Function > function_;
    ::google::protobuf::RepeatedPtrField<std::string> string_table_;
    ::google::protobuf::RepeatedField<::int64_t> comment_;
    mutable ::google::protobuf::internal::CachedSize _comment_cached_byte_size_;
    ::tensorflow::tfprof::pprof::ValueType* period_type_;
    ::int64_t drop_frames_;
    ::int64_t keep_frames_;
    ::int64_t time_nanos_;
    ::int64_t duration_nanos_;
    ::int64_t period_;
    ::int64_t default_sample_type_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto;
};

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// Profile

// repeated .tensorflow.tfprof.pprof.ValueType sample_type = 1;
inline int Profile::_internal_sample_type_size() const {
  return _internal_sample_type().size();
}
inline int Profile::sample_type_size() const {
  return _internal_sample_type_size();
}
inline void Profile::clear_sample_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.sample_type_.Clear();
}
inline ::tensorflow::tfprof::pprof::ValueType* Profile::mutable_sample_type(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:tensorflow.tfprof.pprof.Profile.sample_type)
  return _internal_mutable_sample_type()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::ValueType>* Profile::mutable_sample_type()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Profile.sample_type)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_sample_type();
}
inline const ::tensorflow::tfprof::pprof::ValueType& Profile::sample_type(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.sample_type)
  return _internal_sample_type().Get(index);
}
inline ::tensorflow::tfprof::pprof::ValueType* Profile::add_sample_type() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::tensorflow::tfprof::pprof::ValueType* _add = _internal_mutable_sample_type()->Add();
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Profile.sample_type)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::ValueType>& Profile::sample_type() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Profile.sample_type)
  return _internal_sample_type();
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::ValueType>&
Profile::_internal_sample_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.sample_type_;
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::ValueType>*
Profile::_internal_mutable_sample_type() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.sample_type_;
}

// repeated .tensorflow.tfprof.pprof.Sample sample = 2;
inline int Profile::_internal_sample_size() const {
  return _internal_sample().size();
}
inline int Profile::sample_size() const {
  return _internal_sample_size();
}
inline void Profile::clear_sample() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.sample_.Clear();
}
inline ::tensorflow::tfprof::pprof::Sample* Profile::mutable_sample(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:tensorflow.tfprof.pprof.Profile.sample)
  return _internal_mutable_sample()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Sample>* Profile::mutable_sample()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Profile.sample)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_sample();
}
inline const ::tensorflow::tfprof::pprof::Sample& Profile::sample(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.sample)
  return _internal_sample().Get(index);
}
inline ::tensorflow::tfprof::pprof::Sample* Profile::add_sample() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::tensorflow::tfprof::pprof::Sample* _add = _internal_mutable_sample()->Add();
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Profile.sample)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Sample>& Profile::sample() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Profile.sample)
  return _internal_sample();
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Sample>&
Profile::_internal_sample() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.sample_;
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Sample>*
Profile::_internal_mutable_sample() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.sample_;
}

// repeated .tensorflow.tfprof.pprof.Mapping mapping = 3;
inline int Profile::_internal_mapping_size() const {
  return _internal_mapping().size();
}
inline int Profile::mapping_size() const {
  return _internal_mapping_size();
}
inline void Profile::clear_mapping() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.mapping_.Clear();
}
inline ::tensorflow::tfprof::pprof::Mapping* Profile::mutable_mapping(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:tensorflow.tfprof.pprof.Profile.mapping)
  return _internal_mutable_mapping()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Mapping>* Profile::mutable_mapping()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Profile.mapping)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_mapping();
}
inline const ::tensorflow::tfprof::pprof::Mapping& Profile::mapping(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.mapping)
  return _internal_mapping().Get(index);
}
inline ::tensorflow::tfprof::pprof::Mapping* Profile::add_mapping() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::tensorflow::tfprof::pprof::Mapping* _add = _internal_mutable_mapping()->Add();
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Profile.mapping)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Mapping>& Profile::mapping() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Profile.mapping)
  return _internal_mapping();
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Mapping>&
Profile::_internal_mapping() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.mapping_;
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Mapping>*
Profile::_internal_mutable_mapping() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.mapping_;
}

// repeated .tensorflow.tfprof.pprof.Location location = 4;
inline int Profile::_internal_location_size() const {
  return _internal_location().size();
}
inline int Profile::location_size() const {
  return _internal_location_size();
}
inline void Profile::clear_location() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.location_.Clear();
}
inline ::tensorflow::tfprof::pprof::Location* Profile::mutable_location(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:tensorflow.tfprof.pprof.Profile.location)
  return _internal_mutable_location()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Location>* Profile::mutable_location()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Profile.location)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_location();
}
inline const ::tensorflow::tfprof::pprof::Location& Profile::location(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.location)
  return _internal_location().Get(index);
}
inline ::tensorflow::tfprof::pprof::Location* Profile::add_location() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::tensorflow::tfprof::pprof::Location* _add = _internal_mutable_location()->Add();
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Profile.location)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Location>& Profile::location() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Profile.location)
  return _internal_location();
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Location>&
Profile::_internal_location() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.location_;
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Location>*
Profile::_internal_mutable_location() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.location_;
}

// repeated .tensorflow.tfprof.pprof.Function function = 5;
inline int Profile::_internal_function_size() const {
  return _internal_function().size();
}
inline int Profile::function_size() const {
  return _internal_function_size();
}
inline void Profile::clear_function() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.function_.Clear();
}
inline ::tensorflow::tfprof::pprof::Function* Profile::mutable_function(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:tensorflow.tfprof.pprof.Profile.function)
  return _internal_mutable_function()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Function>* Profile::mutable_function()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Profile.function)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_function();
}
inline const ::tensorflow::tfprof::pprof::Function& Profile::function(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.function)
  return _internal_function().Get(index);
}
inline ::tensorflow::tfprof::pprof::Function* Profile::add_function() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::tensorflow::tfprof::pprof::Function* _add = _internal_mutable_function()->Add();
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Profile.function)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Function>& Profile::function() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Profile.function)
  return _internal_function();
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Function>&
Profile::_internal_function() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.function_;
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Function>*
Profile::_internal_mutable_function() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.function_;
}

// repeated string string_table = 6;
inline int Profile::_internal_string_table_size() const {
  return _internal_string_table().size();
}
inline int Profile::string_table_size() const {
  return _internal_string_table_size();
}
inline void Profile::clear_string_table() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.string_table_.Clear();
}
inline std::string* Profile::add_string_table() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  std::string* _s = _internal_mutable_string_table()->Add();
  // @@protoc_insertion_point(field_add_mutable:tensorflow.tfprof.pprof.Profile.string_table)
  return _s;
}
inline const std::string& Profile::string_table(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.string_table)
  return _internal_string_table().Get(index);
}
inline std::string* Profile::mutable_string_table(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:tensorflow.tfprof.pprof.Profile.string_table)
  return _internal_mutable_string_table()->Mutable(index);
}
template <typename Arg_, typename... Args_>
inline void Profile::set_string_table(int index, Arg_&& value, Args_... args) {
  ::google::protobuf::internal::AssignToString(
      *_internal_mutable_string_table()->Mutable(index),
      std::forward<Arg_>(value), args... );
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Profile.string_table)
}
template <typename Arg_, typename... Args_>
inline void Profile::add_string_table(Arg_&& value, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::google::protobuf::internal::AddToRepeatedPtrField(*_internal_mutable_string_table(),
                               std::forward<Arg_>(value),
                               args... );
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Profile.string_table)
}
inline const ::google::protobuf::RepeatedPtrField<std::string>&
Profile::string_table() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Profile.string_table)
  return _internal_string_table();
}
inline ::google::protobuf::RepeatedPtrField<std::string>*
Profile::mutable_string_table() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Profile.string_table)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_string_table();
}
inline const ::google::protobuf::RepeatedPtrField<std::string>&
Profile::_internal_string_table() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.string_table_;
}
inline ::google::protobuf::RepeatedPtrField<std::string>*
Profile::_internal_mutable_string_table() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.string_table_;
}

// int64 drop_frames = 7;
inline void Profile::clear_drop_frames() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.drop_frames_ = ::int64_t{0};
}
inline ::int64_t Profile::drop_frames() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.drop_frames)
  return _internal_drop_frames();
}
inline void Profile::set_drop_frames(::int64_t value) {
  _internal_set_drop_frames(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Profile.drop_frames)
}
inline ::int64_t Profile::_internal_drop_frames() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.drop_frames_;
}
inline void Profile::_internal_set_drop_frames(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.drop_frames_ = value;
}

// int64 keep_frames = 8;
inline void Profile::clear_keep_frames() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.keep_frames_ = ::int64_t{0};
}
inline ::int64_t Profile::keep_frames() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.keep_frames)
  return _internal_keep_frames();
}
inline void Profile::set_keep_frames(::int64_t value) {
  _internal_set_keep_frames(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Profile.keep_frames)
}
inline ::int64_t Profile::_internal_keep_frames() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.keep_frames_;
}
inline void Profile::_internal_set_keep_frames(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.keep_frames_ = value;
}

// int64 time_nanos = 9;
inline void Profile::clear_time_nanos() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.time_nanos_ = ::int64_t{0};
}
inline ::int64_t Profile::time_nanos() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.time_nanos)
  return _internal_time_nanos();
}
inline void Profile::set_time_nanos(::int64_t value) {
  _internal_set_time_nanos(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Profile.time_nanos)
}
inline ::int64_t Profile::_internal_time_nanos() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.time_nanos_;
}
inline void Profile::_internal_set_time_nanos(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.time_nanos_ = value;
}

// int64 duration_nanos = 10;
inline void Profile::clear_duration_nanos() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.duration_nanos_ = ::int64_t{0};
}
inline ::int64_t Profile::duration_nanos() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.duration_nanos)
  return _internal_duration_nanos();
}
inline void Profile::set_duration_nanos(::int64_t value) {
  _internal_set_duration_nanos(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Profile.duration_nanos)
}
inline ::int64_t Profile::_internal_duration_nanos() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.duration_nanos_;
}
inline void Profile::_internal_set_duration_nanos(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.duration_nanos_ = value;
}

// .tensorflow.tfprof.pprof.ValueType period_type = 11;
inline bool Profile::has_period_type() const {
  bool value = (_impl_._has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || _impl_.period_type_ != nullptr);
  return value;
}
inline void Profile::clear_period_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.period_type_ != nullptr) _impl_.period_type_->Clear();
  _impl_._has_bits_[0] &= ~0x00000001u;
}
inline const ::tensorflow::tfprof::pprof::ValueType& Profile::_internal_period_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::tensorflow::tfprof::pprof::ValueType* p = _impl_.period_type_;
  return p != nullptr ? *p : reinterpret_cast<const ::tensorflow::tfprof::pprof::ValueType&>(::tensorflow::tfprof::pprof::_ValueType_default_instance_);
}
inline const ::tensorflow::tfprof::pprof::ValueType& Profile::period_type() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.period_type)
  return _internal_period_type();
}
inline void Profile::unsafe_arena_set_allocated_period_type(::tensorflow::tfprof::pprof::ValueType* value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.period_type_);
  }
  _impl_.period_type_ = reinterpret_cast<::tensorflow::tfprof::pprof::ValueType*>(value);
  if (value != nullptr) {
    _impl_._has_bits_[0] |= 0x00000001u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:tensorflow.tfprof.pprof.Profile.period_type)
}
inline ::tensorflow::tfprof::pprof::ValueType* Profile::release_period_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  _impl_._has_bits_[0] &= ~0x00000001u;
  ::tensorflow::tfprof::pprof::ValueType* released = _impl_.period_type_;
  _impl_.period_type_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
  released = ::google::protobuf::internal::DuplicateIfNonNull(released);
  if (GetArena() == nullptr) {
    delete old;
  }
#else   // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArena() != nullptr) {
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return released;
}
inline ::tensorflow::tfprof::pprof::ValueType* Profile::unsafe_arena_release_period_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:tensorflow.tfprof.pprof.Profile.period_type)

  _impl_._has_bits_[0] &= ~0x00000001u;
  ::tensorflow::tfprof::pprof::ValueType* temp = _impl_.period_type_;
  _impl_.period_type_ = nullptr;
  return temp;
}
inline ::tensorflow::tfprof::pprof::ValueType* Profile::_internal_mutable_period_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.period_type_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::tensorflow::tfprof::pprof::ValueType>(GetArena());
    _impl_.period_type_ = reinterpret_cast<::tensorflow::tfprof::pprof::ValueType*>(p);
  }
  return _impl_.period_type_;
}
inline ::tensorflow::tfprof::pprof::ValueType* Profile::mutable_period_type() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  _impl_._has_bits_[0] |= 0x00000001u;
  ::tensorflow::tfprof::pprof::ValueType* _msg = _internal_mutable_period_type();
  // @@protoc_insertion_point(field_mutable:tensorflow.tfprof.pprof.Profile.period_type)
  return _msg;
}
inline void Profile::set_allocated_period_type(::tensorflow::tfprof::pprof::ValueType* value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete (_impl_.period_type_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = (value)->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    _impl_._has_bits_[0] |= 0x00000001u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001u;
  }

  _impl_.period_type_ = reinterpret_cast<::tensorflow::tfprof::pprof::ValueType*>(value);
  // @@protoc_insertion_point(field_set_allocated:tensorflow.tfprof.pprof.Profile.period_type)
}

// int64 period = 12;
inline void Profile::clear_period() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.period_ = ::int64_t{0};
}
inline ::int64_t Profile::period() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.period)
  return _internal_period();
}
inline void Profile::set_period(::int64_t value) {
  _internal_set_period(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Profile.period)
}
inline ::int64_t Profile::_internal_period() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.period_;
}
inline void Profile::_internal_set_period(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.period_ = value;
}

// repeated int64 comment = 13;
inline int Profile::_internal_comment_size() const {
  return _internal_comment().size();
}
inline int Profile::comment_size() const {
  return _internal_comment_size();
}
inline void Profile::clear_comment() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.comment_.Clear();
}
inline ::int64_t Profile::comment(int index) const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.comment)
  return _internal_comment().Get(index);
}
inline void Profile::set_comment(int index, ::int64_t value) {
  _internal_mutable_comment()->Set(index, value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Profile.comment)
}
inline void Profile::add_comment(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_comment()->Add(value);
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Profile.comment)
}
inline const ::google::protobuf::RepeatedField<::int64_t>& Profile::comment() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Profile.comment)
  return _internal_comment();
}
inline ::google::protobuf::RepeatedField<::int64_t>* Profile::mutable_comment()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Profile.comment)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_comment();
}
inline const ::google::protobuf::RepeatedField<::int64_t>&
Profile::_internal_comment() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.comment_;
}
inline ::google::protobuf::RepeatedField<::int64_t>* Profile::_internal_mutable_comment() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.comment_;
}

// int64 default_sample_type = 14;
inline void Profile::clear_default_sample_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.default_sample_type_ = ::int64_t{0};
}
inline ::int64_t Profile::default_sample_type() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Profile.default_sample_type)
  return _internal_default_sample_type();
}
inline void Profile::set_default_sample_type(::int64_t value) {
  _internal_set_default_sample_type(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Profile.default_sample_type)
}
inline ::int64_t Profile::_internal_default_sample_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.default_sample_type_;
}
inline void Profile::_internal_set_default_sample_type(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.default_sample_type_ = value;
}

// -------------------------------------------------------------------

// ValueType

// int64 type = 1;
inline void ValueType::clear_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_ = ::int64_t{0};
}
inline ::int64_t ValueType::type() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.ValueType.type)
  return _internal_type();
}
inline void ValueType::set_type(::int64_t value) {
  _internal_set_type(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.ValueType.type)
}
inline ::int64_t ValueType::_internal_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.type_;
}
inline void ValueType::_internal_set_type(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_ = value;
}

// int64 unit = 2;
inline void ValueType::clear_unit() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.unit_ = ::int64_t{0};
}
inline ::int64_t ValueType::unit() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.ValueType.unit)
  return _internal_unit();
}
inline void ValueType::set_unit(::int64_t value) {
  _internal_set_unit(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.ValueType.unit)
}
inline ::int64_t ValueType::_internal_unit() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.unit_;
}
inline void ValueType::_internal_set_unit(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.unit_ = value;
}

// -------------------------------------------------------------------

// Sample

// repeated uint64 location_id = 1;
inline int Sample::_internal_location_id_size() const {
  return _internal_location_id().size();
}
inline int Sample::location_id_size() const {
  return _internal_location_id_size();
}
inline void Sample::clear_location_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.location_id_.Clear();
}
inline ::uint64_t Sample::location_id(int index) const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Sample.location_id)
  return _internal_location_id().Get(index);
}
inline void Sample::set_location_id(int index, ::uint64_t value) {
  _internal_mutable_location_id()->Set(index, value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Sample.location_id)
}
inline void Sample::add_location_id(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_location_id()->Add(value);
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Sample.location_id)
}
inline const ::google::protobuf::RepeatedField<::uint64_t>& Sample::location_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Sample.location_id)
  return _internal_location_id();
}
inline ::google::protobuf::RepeatedField<::uint64_t>* Sample::mutable_location_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Sample.location_id)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_location_id();
}
inline const ::google::protobuf::RepeatedField<::uint64_t>&
Sample::_internal_location_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.location_id_;
}
inline ::google::protobuf::RepeatedField<::uint64_t>* Sample::_internal_mutable_location_id() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.location_id_;
}

// repeated int64 value = 2;
inline int Sample::_internal_value_size() const {
  return _internal_value().size();
}
inline int Sample::value_size() const {
  return _internal_value_size();
}
inline void Sample::clear_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.value_.Clear();
}
inline ::int64_t Sample::value(int index) const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Sample.value)
  return _internal_value().Get(index);
}
inline void Sample::set_value(int index, ::int64_t value) {
  _internal_mutable_value()->Set(index, value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Sample.value)
}
inline void Sample::add_value(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_value()->Add(value);
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Sample.value)
}
inline const ::google::protobuf::RepeatedField<::int64_t>& Sample::value() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Sample.value)
  return _internal_value();
}
inline ::google::protobuf::RepeatedField<::int64_t>* Sample::mutable_value()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Sample.value)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_value();
}
inline const ::google::protobuf::RepeatedField<::int64_t>&
Sample::_internal_value() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.value_;
}
inline ::google::protobuf::RepeatedField<::int64_t>* Sample::_internal_mutable_value() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.value_;
}

// repeated .tensorflow.tfprof.pprof.Label label = 3;
inline int Sample::_internal_label_size() const {
  return _internal_label().size();
}
inline int Sample::label_size() const {
  return _internal_label_size();
}
inline void Sample::clear_label() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.label_.Clear();
}
inline ::tensorflow::tfprof::pprof::Label* Sample::mutable_label(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:tensorflow.tfprof.pprof.Sample.label)
  return _internal_mutable_label()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Label>* Sample::mutable_label()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Sample.label)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_label();
}
inline const ::tensorflow::tfprof::pprof::Label& Sample::label(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Sample.label)
  return _internal_label().Get(index);
}
inline ::tensorflow::tfprof::pprof::Label* Sample::add_label() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::tensorflow::tfprof::pprof::Label* _add = _internal_mutable_label()->Add();
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Sample.label)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Label>& Sample::label() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Sample.label)
  return _internal_label();
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Label>&
Sample::_internal_label() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.label_;
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Label>*
Sample::_internal_mutable_label() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.label_;
}

// -------------------------------------------------------------------

// Label

// int64 key = 1;
inline void Label::clear_key() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.key_ = ::int64_t{0};
}
inline ::int64_t Label::key() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Label.key)
  return _internal_key();
}
inline void Label::set_key(::int64_t value) {
  _internal_set_key(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Label.key)
}
inline ::int64_t Label::_internal_key() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.key_;
}
inline void Label::_internal_set_key(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.key_ = value;
}

// int64 str = 2;
inline void Label::clear_str() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.str_ = ::int64_t{0};
}
inline ::int64_t Label::str() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Label.str)
  return _internal_str();
}
inline void Label::set_str(::int64_t value) {
  _internal_set_str(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Label.str)
}
inline ::int64_t Label::_internal_str() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.str_;
}
inline void Label::_internal_set_str(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.str_ = value;
}

// int64 num = 3;
inline void Label::clear_num() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.num_ = ::int64_t{0};
}
inline ::int64_t Label::num() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Label.num)
  return _internal_num();
}
inline void Label::set_num(::int64_t value) {
  _internal_set_num(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Label.num)
}
inline ::int64_t Label::_internal_num() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.num_;
}
inline void Label::_internal_set_num(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.num_ = value;
}

// -------------------------------------------------------------------

// Mapping

// uint64 id = 1;
inline void Mapping::clear_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.id_ = ::uint64_t{0u};
}
inline ::uint64_t Mapping::id() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Mapping.id)
  return _internal_id();
}
inline void Mapping::set_id(::uint64_t value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Mapping.id)
}
inline ::uint64_t Mapping::_internal_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.id_;
}
inline void Mapping::_internal_set_id(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.id_ = value;
}

// uint64 memory_start = 2;
inline void Mapping::clear_memory_start() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.memory_start_ = ::uint64_t{0u};
}
inline ::uint64_t Mapping::memory_start() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Mapping.memory_start)
  return _internal_memory_start();
}
inline void Mapping::set_memory_start(::uint64_t value) {
  _internal_set_memory_start(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Mapping.memory_start)
}
inline ::uint64_t Mapping::_internal_memory_start() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.memory_start_;
}
inline void Mapping::_internal_set_memory_start(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.memory_start_ = value;
}

// uint64 memory_limit = 3;
inline void Mapping::clear_memory_limit() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.memory_limit_ = ::uint64_t{0u};
}
inline ::uint64_t Mapping::memory_limit() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Mapping.memory_limit)
  return _internal_memory_limit();
}
inline void Mapping::set_memory_limit(::uint64_t value) {
  _internal_set_memory_limit(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Mapping.memory_limit)
}
inline ::uint64_t Mapping::_internal_memory_limit() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.memory_limit_;
}
inline void Mapping::_internal_set_memory_limit(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.memory_limit_ = value;
}

// uint64 file_offset = 4;
inline void Mapping::clear_file_offset() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.file_offset_ = ::uint64_t{0u};
}
inline ::uint64_t Mapping::file_offset() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Mapping.file_offset)
  return _internal_file_offset();
}
inline void Mapping::set_file_offset(::uint64_t value) {
  _internal_set_file_offset(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Mapping.file_offset)
}
inline ::uint64_t Mapping::_internal_file_offset() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.file_offset_;
}
inline void Mapping::_internal_set_file_offset(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.file_offset_ = value;
}

// int64 filename = 5;
inline void Mapping::clear_filename() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.filename_ = ::int64_t{0};
}
inline ::int64_t Mapping::filename() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Mapping.filename)
  return _internal_filename();
}
inline void Mapping::set_filename(::int64_t value) {
  _internal_set_filename(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Mapping.filename)
}
inline ::int64_t Mapping::_internal_filename() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.filename_;
}
inline void Mapping::_internal_set_filename(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.filename_ = value;
}

// int64 build_id = 6;
inline void Mapping::clear_build_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.build_id_ = ::int64_t{0};
}
inline ::int64_t Mapping::build_id() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Mapping.build_id)
  return _internal_build_id();
}
inline void Mapping::set_build_id(::int64_t value) {
  _internal_set_build_id(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Mapping.build_id)
}
inline ::int64_t Mapping::_internal_build_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.build_id_;
}
inline void Mapping::_internal_set_build_id(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.build_id_ = value;
}

// bool has_functions = 7;
inline void Mapping::clear_has_functions() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.has_functions_ = false;
}
inline bool Mapping::has_functions() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Mapping.has_functions)
  return _internal_has_functions();
}
inline void Mapping::set_has_functions(bool value) {
  _internal_set_has_functions(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Mapping.has_functions)
}
inline bool Mapping::_internal_has_functions() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.has_functions_;
}
inline void Mapping::_internal_set_has_functions(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.has_functions_ = value;
}

// bool has_filenames = 8;
inline void Mapping::clear_has_filenames() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.has_filenames_ = false;
}
inline bool Mapping::has_filenames() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Mapping.has_filenames)
  return _internal_has_filenames();
}
inline void Mapping::set_has_filenames(bool value) {
  _internal_set_has_filenames(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Mapping.has_filenames)
}
inline bool Mapping::_internal_has_filenames() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.has_filenames_;
}
inline void Mapping::_internal_set_has_filenames(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.has_filenames_ = value;
}

// bool has_line_numbers = 9;
inline void Mapping::clear_has_line_numbers() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.has_line_numbers_ = false;
}
inline bool Mapping::has_line_numbers() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Mapping.has_line_numbers)
  return _internal_has_line_numbers();
}
inline void Mapping::set_has_line_numbers(bool value) {
  _internal_set_has_line_numbers(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Mapping.has_line_numbers)
}
inline bool Mapping::_internal_has_line_numbers() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.has_line_numbers_;
}
inline void Mapping::_internal_set_has_line_numbers(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.has_line_numbers_ = value;
}

// bool has_inline_frames = 10;
inline void Mapping::clear_has_inline_frames() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.has_inline_frames_ = false;
}
inline bool Mapping::has_inline_frames() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Mapping.has_inline_frames)
  return _internal_has_inline_frames();
}
inline void Mapping::set_has_inline_frames(bool value) {
  _internal_set_has_inline_frames(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Mapping.has_inline_frames)
}
inline bool Mapping::_internal_has_inline_frames() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.has_inline_frames_;
}
inline void Mapping::_internal_set_has_inline_frames(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.has_inline_frames_ = value;
}

// -------------------------------------------------------------------

// Location

// uint64 id = 1;
inline void Location::clear_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.id_ = ::uint64_t{0u};
}
inline ::uint64_t Location::id() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Location.id)
  return _internal_id();
}
inline void Location::set_id(::uint64_t value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Location.id)
}
inline ::uint64_t Location::_internal_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.id_;
}
inline void Location::_internal_set_id(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.id_ = value;
}

// uint64 mapping_id = 2;
inline void Location::clear_mapping_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.mapping_id_ = ::uint64_t{0u};
}
inline ::uint64_t Location::mapping_id() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Location.mapping_id)
  return _internal_mapping_id();
}
inline void Location::set_mapping_id(::uint64_t value) {
  _internal_set_mapping_id(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Location.mapping_id)
}
inline ::uint64_t Location::_internal_mapping_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.mapping_id_;
}
inline void Location::_internal_set_mapping_id(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.mapping_id_ = value;
}

// uint64 address = 3;
inline void Location::clear_address() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.address_ = ::uint64_t{0u};
}
inline ::uint64_t Location::address() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Location.address)
  return _internal_address();
}
inline void Location::set_address(::uint64_t value) {
  _internal_set_address(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Location.address)
}
inline ::uint64_t Location::_internal_address() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.address_;
}
inline void Location::_internal_set_address(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.address_ = value;
}

// repeated .tensorflow.tfprof.pprof.Line line = 4;
inline int Location::_internal_line_size() const {
  return _internal_line().size();
}
inline int Location::line_size() const {
  return _internal_line_size();
}
inline void Location::clear_line() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.line_.Clear();
}
inline ::tensorflow::tfprof::pprof::Line* Location::mutable_line(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:tensorflow.tfprof.pprof.Location.line)
  return _internal_mutable_line()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Line>* Location::mutable_line()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable_list:tensorflow.tfprof.pprof.Location.line)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_line();
}
inline const ::tensorflow::tfprof::pprof::Line& Location::line(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Location.line)
  return _internal_line().Get(index);
}
inline ::tensorflow::tfprof::pprof::Line* Location::add_line() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::tensorflow::tfprof::pprof::Line* _add = _internal_mutable_line()->Add();
  // @@protoc_insertion_point(field_add:tensorflow.tfprof.pprof.Location.line)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Line>& Location::line() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:tensorflow.tfprof.pprof.Location.line)
  return _internal_line();
}
inline const ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Line>&
Location::_internal_line() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.line_;
}
inline ::google::protobuf::RepeatedPtrField<::tensorflow::tfprof::pprof::Line>*
Location::_internal_mutable_line() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.line_;
}

// -------------------------------------------------------------------

// Line

// uint64 function_id = 1;
inline void Line::clear_function_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.function_id_ = ::uint64_t{0u};
}
inline ::uint64_t Line::function_id() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Line.function_id)
  return _internal_function_id();
}
inline void Line::set_function_id(::uint64_t value) {
  _internal_set_function_id(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Line.function_id)
}
inline ::uint64_t Line::_internal_function_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.function_id_;
}
inline void Line::_internal_set_function_id(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.function_id_ = value;
}

// int64 line = 2;
inline void Line::clear_line() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.line_ = ::int64_t{0};
}
inline ::int64_t Line::line() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Line.line)
  return _internal_line();
}
inline void Line::set_line(::int64_t value) {
  _internal_set_line(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Line.line)
}
inline ::int64_t Line::_internal_line() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.line_;
}
inline void Line::_internal_set_line(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.line_ = value;
}

// -------------------------------------------------------------------

// Function

// uint64 id = 1;
inline void Function::clear_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.id_ = ::uint64_t{0u};
}
inline ::uint64_t Function::id() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Function.id)
  return _internal_id();
}
inline void Function::set_id(::uint64_t value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Function.id)
}
inline ::uint64_t Function::_internal_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.id_;
}
inline void Function::_internal_set_id(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.id_ = value;
}

// int64 name = 2;
inline void Function::clear_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_ = ::int64_t{0};
}
inline ::int64_t Function::name() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Function.name)
  return _internal_name();
}
inline void Function::set_name(::int64_t value) {
  _internal_set_name(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Function.name)
}
inline ::int64_t Function::_internal_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.name_;
}
inline void Function::_internal_set_name(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_ = value;
}

// int64 system_name = 3;
inline void Function::clear_system_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.system_name_ = ::int64_t{0};
}
inline ::int64_t Function::system_name() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Function.system_name)
  return _internal_system_name();
}
inline void Function::set_system_name(::int64_t value) {
  _internal_set_system_name(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Function.system_name)
}
inline ::int64_t Function::_internal_system_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.system_name_;
}
inline void Function::_internal_set_system_name(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.system_name_ = value;
}

// int64 filename = 4;
inline void Function::clear_filename() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.filename_ = ::int64_t{0};
}
inline ::int64_t Function::filename() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Function.filename)
  return _internal_filename();
}
inline void Function::set_filename(::int64_t value) {
  _internal_set_filename(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Function.filename)
}
inline ::int64_t Function::_internal_filename() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.filename_;
}
inline void Function::_internal_set_filename(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.filename_ = value;
}

// int64 start_line = 5;
inline void Function::clear_start_line() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.start_line_ = ::int64_t{0};
}
inline ::int64_t Function::start_line() const {
  // @@protoc_insertion_point(field_get:tensorflow.tfprof.pprof.Function.start_line)
  return _internal_start_line();
}
inline void Function::set_start_line(::int64_t value) {
  _internal_set_start_line(value);
  // @@protoc_insertion_point(field_set:tensorflow.tfprof.pprof.Function.start_line)
}
inline ::int64_t Function::_internal_start_line() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.start_line_;
}
inline void Function::_internal_set_start_line(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.start_line_ = value;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace pprof
}  // namespace tfprof
}  // namespace tensorflow


// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"

#endif  // GOOGLE_PROTOBUF_INCLUDED_tsl_2fprofiler_2fprotobuf_2fprofile_2eproto_2epb_2eh
